%------------------------------------------------------------------
% Plots a triangle with defined top coordinates, height, base,
% orientation, and color.
% This method is used to draw translation constraints on 2D models.
% Input arguments:
%  where: axes where drawing is being made
%  x: top coordinate on the X axis
%  y: top coordinate on the Y axis
%  h: triangle height
%  B: triangle base
%  ang: angle (in radian) between the axis of symmetry and the
%       horizontal direction (counterclockwise) - 0 rad when
%       triangle is pointing left
%  c: color (RGB vector)
function triangle(where,x,y,h,B,ang,c)
    b = B/2;
    
    cx = cos(ang);
    cy = sin(ang);
    
    X = [x, x + h * cx + b * cy, x + h * cx - b * cy];
    Y = [y, y + h * cy - b * cx, y + h * cy + b * cx];
    fill(where,X, Y, c);
end